.. _module_hydra_core_hookhead:

hookhead
========

This sections contains module documentation of hookhead module.

hookhead
^^^^^^^^

Method provides class ModuleLoader with Python system hooks.
Unit tests available at hydratk/core/hookhead/01_methods_ut.jedi

**Attributes** :

* _package_path

**Methods** :

* find_module

Method import module langtexts if configured in packages_map. Currently used for hydratk-lib-network langtexts.

* load_module

Method loads given module.